==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/PropertyEditorDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorDataSourceDescription } from "./PropertyEditorDataSourceDescription";
/**
 * @hidden
 */
export let PropertyEditorDataSourceDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyEditorDataSourceDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyEditorDataSourceDescriptionMetadata.a == null) {
                PropertyEditorDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyEditorDataSourceDescriptionMetadata.c(PropertyEditorDataSourceDescriptionMetadata.a);
            }
            if (a.k(PropertyEditorDataSourceDescriptionMetadata.a)) {
                return;
            }
            a.ab(PropertyEditorDataSourceDescriptionMetadata.a);
        }
        static c(a) {
            a.item("DescriptionType", "String");
            a.item("ContextRef", "(w:Context,wf:Context)DataRef::object");
        }
        static d(a) {
            PropertyEditorDataSourceDescriptionMetadata.b(a);
            a.ad("PropertyEditorDataSource", () => new PropertyEditorDataSourceDescription());
            a.ac("PropertyEditorDataSource", PropertyEditorDataSourceDescriptionMetadata.a);
        }
    }
    PropertyEditorDataSourceDescriptionMetadata.$t = markType(PropertyEditorDataSourceDescriptionMetadata, 'PropertyEditorDataSourceDescriptionMetadata');
    PropertyEditorDataSourceDescriptionMetadata.a = null;
    return PropertyEditorDataSourceDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/PropertyEditorDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorDataSourceDescription } from "./PropertyEditorDataSourceDescription";
/**
 * @hidden
 */
export let PropertyEditorDataSourceDescriptionMetadata = /*@__PURE__*/ (() => {
    class PropertyEditorDataSourceDescriptionMetadata extends Base {
        static b(a) {
            if (PropertyEditorDataSourceDescriptionMetadata.a == null) {
                PropertyEditorDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PropertyEditorDataSourceDescriptionMetadata.c(PropertyEditorDataSourceDescriptionMetadata.a);
            }
            if (a.k(PropertyEditorDataSourceDescriptionMetadata.a)) {
                return;
            }
            a.ac(PropertyEditorDataSourceDescriptionMetadata.a);
        }
        static c(a) {
            a.item("DescriptionType", "String");
            a.item("ContextRef", "(w:Context,wf:Context)DataRef::object");
        }
        static d(a) {
            PropertyEditorDataSourceDescriptionMetadata.b(a);
            a.ae("PropertyEditorDataSource", () => new PropertyEditorDataSourceDescription());
            a.ad("PropertyEditorDataSource", PropertyEditorDataSourceDescriptionMetadata.a);
        }
    }
    PropertyEditorDataSourceDescriptionMetadata.$t = markType(PropertyEditorDataSourceDescriptionMetadata, 'PropertyEditorDataSourceDescriptionMetadata');
    PropertyEditorDataSourceDescriptionMetadata.a = null;
    return PropertyEditorDataSourceDescriptionMetadata;
})();
